@@ -61,7 +61,7 @@ class AuthenticationMixin:
 
     def validate_claims(self, claims):
         expected_list = [settings.OIDC_OP_EXPECTED_EMAIL_CLAIM] + list(settings.OIDC_OP_EXPECTED_CLAIMS)
-        debug(f"Validate {claims=} against expected {expected_list}")
+        debug(f"Validate claims={claims} against expected {expected_list}")
         for expected in expected_list:
             if expected not in claims:
                 raise SuspiciousOperation(f"'{expected}' claim was expected")
